@@ -4,9 +4,9 @@ use 5.010001;
 use strict 'subs', 'vars';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-09'; # DATE
+our $DATE = '2024-01-17'; # DATE
 our $DIST = 'Data-Sah-DefaultValue'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our %common_args = (
     default_value_rules => {
@@ -89,8 +89,20 @@ sub get_default_value_rules {
 
     my @rules;
     for my $item (@rules0) {
-        my $rule_name = ref $item eq 'ARRAY' ? $item->[0] : $item;
-        my $rule_gen_args = ref $item eq 'ARRAY' ? $item->[1] : undef;
+        my ($rule_name, $rule_gen_args);
+        if (ref $item eq 'ARRAY') {
+            $rule_name = $item->[0];
+            $rule_gen_args = $item->[1];
+        } else {
+            if ($item =~ /(.*?)=(.*)/) {
+                $rule_name = $1;
+                $rule_gen_args = {split /,/, $2};
+            } else {
+                $rule_name = $item;
+                $rule_gen_args = undef;
+            }
+        }
+
         my $mod = $prefix . $rule_name;
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
@@ -129,7 +141,7 @@ Data::Sah::DefaultValueCommon - Common stuffs for Data::Sah::DefaultValue and Da
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::DefaultValueCommon (from Perl distribution Data-Sah-DefaultValue), released on 2023-12-09.
+This document describes version 0.005 of Data::Sah::DefaultValueCommon (from Perl distribution Data-Sah-DefaultValue), released on 2024-01-17.
 
 =head1 FUNCTIONS
 
@@ -226,7 +238,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
